Module flow_chart

Module flow_chart 

Structs

ConnectionConfig
A struct representing the possible attributes for a Connection.
FlowChart
This is the root struct for an individual flow chart.
NodeConfig
A struct representing the possible attributes for a Node.

Enums

ArrowDirection
The various different arrow directions enabled by this syntax.
ArrowType
The various different arrow types enabled by this syntax.
LineType
The various different line types enabled by this syntax.
ObjectConfig
An enum representation of either a NodeConfig or a ConnectionConfig.
Shape
The various different shapes enabled by this syntax.