ConnectionConfig

Struct ConnectionConfig 

pub struct ConnectionConfig {
    pub line_type: LineType,
    pub arrow_type: ArrowType,
    pub arrow_direction: ArrowDirection,
    pub extra_length_num: Option<u8>,
}
A struct representing the possible attributes for a Connection.

Fields

line_type: LineType

The enum representation of the type of line you want

arrow_type: ArrowType

The enum representation of the type of arrow you want

arrow_direction: ArrowDirection

The enum representation of the direction you want the arrows to point

extra_length_num: Option<u8>

An optional amount of additional flags to increase line length