NodeConfig

Struct NodeConfig 

pub struct NodeConfig<'a> {
    pub id: &'a str,
    pub class: Option<String>,
    pub shape: Shape,
    pub inner_text: &'a str,
}
A struct representing the possible attributes for a Node.

Fields

id: &'a str

The ID that will be assigned to this node

class: Option<String>

An optional class name to assign to the node

shape: Shape

The shape of the node

inner_text: &'a str

The text to be displayed within the node