Structs
- Connection
Config - A struct representing the possible attributes for a Connection.
- Flow
Chart - This is the root struct for an individual flow chart.
- Node
Config - A struct representing the possible attributes for a Node.
Enums
- Arrow
Direction - The various different arrow directions enabled by this syntax.
- Arrow
Type - The various different arrow types enabled by this syntax.
- Line
Type - The various different line types enabled by this syntax.
- Object
Config - An enum representation of either a NodeConfig or a ConnectionConfig.
- Shape
- The various different shapes enabled by this syntax.